GetLithologicalLogInformation
^^^^^^^^^^^^^^^^^^^^^^^^^^^^^

You can request a single drillhole number (DHNO) (see search queries above for how to obtain this number).

`GetLithologicalLogInformation?DHNO=27773 <https://www.waterconnect.sa.gov.au/_layouts/15/dfw.sharepoint.wdd/WDDDMS.ashx/GetLithologicalLogInformation?DHNO=27773>`__

.. code-block:: json

    [
      {
        "DRILLHOLE_NO": 27773,
        "LITHO_DEPTH_FROM": 0,
        "LITHO_DEPTH_TO": 2,
        "LITHO_APPROVED_CODE1": "SAND",
        "LITHO_DESC": "fine light brown sand, well sorted, carbonate present"
      },
      {
        "DRILLHOLE_NO": 27773,
        "LITHO_DEPTH_FROM": 150,
        "LITHO_DEPTH_TO": 174,
        "LITHO_APPROVED_CODE1": "CLYU",
        "LITHO_APPROVED_CODE2": "SILT",
        "LITHO_DESC": "silty clay, light brown coloured, high carbonate content, shell fragments"
      }
    ]